@@ -25,19 +25,19 @@ from oslo_config import cfg
 from oslo_serialization import base64
 from oslo_service import loopingcall
 from oslo_utils import imageutils
-from oslotest import base as test_base
 import requests
 
 from ironic_lib import disk_partitioner
 from ironic_lib import disk_utils
 from ironic_lib import exception
+from ironic_lib.tests import base
 from ironic_lib import utils
 
 CONF = cfg.CONF
 
 
 @mock.patch.object(utils, 'execute', autospec=True)
-class ListPartitionsTestCase(test_base.BaseTestCase):
+class ListPartitionsTestCase(base.IronicLibTestCase):
 
     def test_correct(self, execute_mock):
         output = """
@@ -72,7 +72,7 @@ BYT;
 
 
 @mock.patch.object(disk_partitioner.DiskPartitioner, 'commit', lambda _: None)
-class WorkOnDiskTestCase(test_base.BaseTestCase):
+class WorkOnDiskTestCase(base.IronicLibTestCase):
 
     def setUp(self):
         super(WorkOnDiskTestCase, self).setUp()
@@ -294,7 +294,7 @@ class WorkOnDiskTestCase(test_base.BaseTestCase):
 
 
 @mock.patch.object(utils, 'execute', autospec=True)
-class MakePartitionsTestCase(test_base.BaseTestCase):
+class MakePartitionsTestCase(base.IronicLibTestCase):
 
     def setUp(self):
         super(MakePartitionsTestCase, self).setUp()
@@ -421,6 +421,29 @@ class MakePartitionsTestCase(test_base.BaseTestCase):
         mock_exc.assert_has_calls([parted_call])
         self.assertEqual(expected_result, result)
 
+    def test_make_partitions_with_nvme_device(self, mock_exc):
+        self.ephemeral_mb = 2048
+        expected_mkpart = ['mkpart', 'primary', '', '1', '2049',
+                           'mkpart', 'primary', 'linux-swap', '2049', '2561',
+                           'mkpart', 'primary', '', '2561', '3585']
+        self.dev = '/dev/nvmefake-9'
+        ep = '/dev/nvmefake-9p1'
+        swap = '/dev/nvmefake-9p2'
+        root = '/dev/nvmefake-9p3'
+        expected_result = {'ephemeral': ep,
+                           'swap': swap,
+                           'root': root}
+        cmd = self._get_parted_cmd(self.dev) + expected_mkpart
+        mock_exc.return_value = (None, None)
+        result = disk_utils.make_partitions(
+            self.dev, self.root_mb, self.swap_mb, self.ephemeral_mb,
+            self.configdrive_mb, self.node_uuid)
+
+        parted_call = mock.call(*cmd, use_standard_locale=True,
+                                run_as_root=True, check_exit_code=[0])
+        mock_exc.assert_has_calls([parted_call])
+        self.assertEqual(expected_result, result)
+
     def test_make_partitions_with_local_device(self, mock_exc):
         self.ephemeral_mb = 2048
         expected_mkpart = ['mkpart', 'primary', '', '1', '2049',
@@ -443,7 +466,7 @@ class MakePartitionsTestCase(test_base.BaseTestCase):
 
 
 @mock.patch.object(utils, 'execute', autospec=True)
-class DestroyMetaDataTestCase(test_base.BaseTestCase):
+class DestroyMetaDataTestCase(base.IronicLibTestCase):
 
     def setUp(self):
         super(DestroyMetaDataTestCase, self).setUp()
@@ -452,6 +475,9 @@ class DestroyMetaDataTestCase(test_base.BaseTestCase):
 
     def test_destroy_disk_metadata(self, mock_exec):
         expected_calls = [mock.call('wipefs', '--force', '--all', 'fake-dev',
+                                    run_as_root=True,
+                                    use_standard_locale=True),
+                          mock.call('sgdisk', '-Z', 'fake-dev',
                                     run_as_root=True,
                                     use_standard_locale=True)]
         disk_utils.destroy_disk_metadata(self.dev, self.node_uuid)
@@ -469,9 +495,25 @@ class DestroyMetaDataTestCase(test_base.BaseTestCase):
                           self.node_uuid)
         mock_exec.assert_has_calls(expected_call)
 
+    def test_destroy_disk_metadata_sgdisk_fail(self, mock_exec):
+        expected_calls = [mock.call('wipefs', '--force', '--all', 'fake-dev',
+                                    run_as_root=True,
+                                    use_standard_locale=True),
+                          mock.call('sgdisk', '-Z', 'fake-dev',
+                                    run_as_root=True,
+                                    use_standard_locale=True)]
+        mock_exec.side_effect = [(None, None),
+                                 processutils.ProcessExecutionError()]
+        self.assertRaises(processutils.ProcessExecutionError,
+                          disk_utils.destroy_disk_metadata,
+                          self.dev,
+                          self.node_uuid)
+        mock_exec.assert_has_calls(expected_calls)
+
     def test_destroy_disk_metadata_wipefs_not_support_force(self, mock_exec):
         mock_exec.side_effect = iter(
             [processutils.ProcessExecutionError(description='--force'),
+             (None, None),
              (None, None)])
 
         expected_call = [mock.call('wipefs', '--force', '--all', 'fake-dev',
@@ -485,7 +527,7 @@ class DestroyMetaDataTestCase(test_base.BaseTestCase):
 
 
 @mock.patch.object(utils, 'execute', autospec=True)
-class GetDeviceBlockSizeTestCase(test_base.BaseTestCase):
+class GetDeviceBlockSizeTestCase(base.IronicLibTestCase):
 
     def setUp(self):
         super(GetDeviceBlockSizeTestCase, self).setUp()
@@ -503,10 +545,7 @@ class GetDeviceBlockSizeTestCase(test_base.BaseTestCase):
 @mock.patch.object(disk_utils, 'dd', autospec=True)
 @mock.patch.object(disk_utils, 'qemu_img_info', autospec=True)
 @mock.patch.object(disk_utils, 'convert_image', autospec=True)
-class PopulateImageTestCase(test_base.BaseTestCase):
-
-    def setUp(self):
-        super(PopulateImageTestCase, self).setUp()
+class PopulateImageTestCase(base.IronicLibTestCase):
 
     def test_populate_raw_image(self, mock_cg, mock_qinfo, mock_dd):
         type(mock_qinfo.return_value).file_format = mock.PropertyMock(
@@ -537,7 +576,7 @@ def _looping_call_done(*args, **kwargs):
 @mock.patch.object(utils, 'mkfs', lambda fs, path, label=None: None)
 # NOTE(dtantsur): destroy_disk_metadata resets file size, disabling it
 @mock.patch.object(disk_utils, 'destroy_disk_metadata', lambda *_: None)
-class RealFilePartitioningTestCase(test_base.BaseTestCase):
+class RealFilePartitioningTestCase(base.IronicLibTestCase):
     """This test applies some real-world partitioning scenario to a file.
 
     This test covers the whole partitioning, mocking everything not possible
@@ -545,6 +584,9 @@ class RealFilePartitioningTestCase(test_base.BaseTestCase):
     and also conducts integration testing of DiskPartitioner.
     """
 
+    # Allow calls to utils.execute() and related functions
+    block_execute = False
+
     def setUp(self):
         super(RealFilePartitioningTestCase, self).setUp()
         # NOTE(dtantsur): no parted utility on gate-ironic-python26
@@ -608,7 +650,7 @@ class RealFilePartitioningTestCase(test_base.BaseTestCase):
 
 @mock.patch.object(shutil, 'copyfileobj', autospec=True)
 @mock.patch.object(requests, 'get', autospec=True)
-class GetConfigdriveTestCase(test_base.BaseTestCase):
+class GetConfigdriveTestCase(base.IronicLibTestCase):
 
     @mock.patch.object(gzip, 'GzipFile', autospec=True)
     def test_get_configdrive(self, mock_gzip, mock_requests, mock_copy):
@@ -664,7 +706,7 @@ class GetConfigdriveTestCase(test_base.BaseTestCase):
 
 
 @mock.patch('time.sleep', lambda sec: None)
-class OtherFunctionTestCase(test_base.BaseTestCase):
+class OtherFunctionTestCase(base.IronicLibTestCase):
 
     @mock.patch.object(os, 'stat', autospec=True)
     @mock.patch.object(stat, 'S_ISBLK', autospec=True)
@@ -772,7 +814,7 @@ class OtherFunctionTestCase(test_base.BaseTestCase):
 
 
 @mock.patch.object(utils, 'execute', autospec=True)
-class WholeDiskPartitionTestCases(test_base.BaseTestCase):
+class WholeDiskPartitionTestCases(base.IronicLibTestCase):
 
     def setUp(self):
         super(WholeDiskPartitionTestCases, self).setUp()
@@ -796,6 +838,22 @@ class WholeDiskPartitionTestCases(test_base.BaseTestCase):
         ]
         mock_execute.assert_has_calls(execute_calls)
 
+    def test_get_partition_present_uppercase(self, mock_execute):
+        lsblk_output = 'NAME="fake12" LABEL="CONFIG-2"\n'
+        part_result = '/dev/fake12'
+        mock_execute.side_effect = [(None, ''), (lsblk_output, '')]
+        result = disk_utils._get_labelled_partition(self.dev,
+                                                    self.config_part_label,
+                                                    self.node_uuid)
+        self.assertEqual(part_result, result)
+        execute_calls = [
+            mock.call('partprobe', self.dev, run_as_root=True, attempts=10),
+            mock.call('lsblk', '-Po', 'name,label', self.dev,
+                      check_exit_code=[0, 1],
+                      use_standard_locale=True, run_as_root=True)
+        ]
+        mock_execute.assert_has_calls(execute_calls)
+
     def test_get_partition_absent(self, mock_execute):
         mock_execute.side_effect = [(None, ''),
                                     (None, '')]
@@ -909,18 +967,17 @@ class WholeDiskPartitionTestCases(test_base.BaseTestCase):
         self.assertEqual(1, mock_log.call_count)
 
     def test_fix_gpt_structs_fix_required(self, mock_execute):
-        partprobe_err = """
-Error: The backup GPT table is not at the end of the disk, as it should be.
-This might mean that another operating system believes the disk is smaller.
-Fix, by moving the backup to the end (and removing the old backup)?
-Warning: Not all of the space available to /dev/sdb appears to be used,
-you can fix the GPT to use all of the space (an extra 581456476 blocks)
-or continue with the current setting?
+        sgdisk_v_output = """
+Problem: The secondary header's self-pointer indicates that it doesn't reside
+at the end of the disk. If you've added a disk to a RAID array, use the 'e'
+option on the experts' menu to adjust the secondary header's and partition
+table's locations.
+
+Identified 1 problems!
 """
-        mock_execute.return_value = ('', partprobe_err)
+        mock_execute.return_value = (sgdisk_v_output, '')
         execute_calls = [
-            mock.call('partprobe', '/dev/fake', use_standard_locale=True,
-                      run_as_root=True),
+            mock.call('sgdisk', '-v', '/dev/fake', run_as_root=True),
             mock.call('sgdisk', '-e', '/dev/fake', run_as_root=True)
         ]
         disk_utils._fix_gpt_structs('/dev/fake', self.node_uuid)
@@ -930,8 +987,7 @@ or continue with the current setting?
         mock_execute.return_value = ('', '')
 
         disk_utils._fix_gpt_structs('/dev/fake', self.node_uuid)
-        mock_execute.assert_called_once_with('partprobe', '/dev/fake',
-                                             use_standard_locale=True,
+        mock_execute.assert_called_once_with('sgdisk', '-v', '/dev/fake',
                                              run_as_root=True)
 
     @mock.patch.object(disk_utils.LOG, 'error', autospec=True)
@@ -941,13 +997,12 @@ or continue with the current setting?
                                'Failed to fix GPT data structures on disk',
                                disk_utils._fix_gpt_structs,
                                self.dev, self.node_uuid)
-        mock_execute.assert_called_once_with('partprobe', '/dev/fake',
-                                             use_standard_locale=True,
+        mock_execute.assert_called_once_with('sgdisk', '-v', '/dev/fake',
                                              run_as_root=True)
         self.assertEqual(1, mock_log.call_count)
 
 
-class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
+class WholeDiskConfigDriveTestCases(base.IronicLibTestCase):
 
     def setUp(self):
         super(WholeDiskConfigDriveTestCases, self).setUp()
@@ -960,6 +1015,8 @@ class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
                        autospec=True)
     @mock.patch.object(disk_utils, 'dd',
                        autospec=True)
+    @mock.patch.object(disk_utils, '_fix_gpt_partition',
+                       autospec=True)
     @mock.patch.object(disk_utils, '_fix_gpt_structs',
                        autospec=True)
     @mock.patch.object(disk_utils, '_is_disk_gpt_partitioned',
@@ -972,8 +1029,8 @@ class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
                        autospec=True)
     def test_create_partition_exists(self, mock_get_configdrive,
                                      mock_get_labelled_partition,
-                                     mock_list_partitions,
-                                     mock_is_disk_gpt, mock_fix_gpt,
+                                     mock_list_partitions, mock_is_disk_gpt,
+                                     mock_fix_gpt, mock_fix_gpt_partition,
                                      mock_dd, mock_unlink, mock_execute):
         config_url = 'http://1.2.3.4/cd'
         configdrive_part = '/dev/fake-part1'
@@ -984,13 +1041,15 @@ class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
         mock_get_configdrive.return_value = (configdrive_mb, configdrive_file)
         disk_utils.create_config_drive_partition(self.node_uuid, self.dev,
                                                  config_url)
+        mock_fix_gpt_partition.assert_called_with(self.dev, self.node_uuid)
         mock_get_configdrive.assert_called_with(config_url, self.node_uuid)
         mock_get_labelled_partition.assert_called_with(self.dev,
                                                        self.config_part_label,
                                                        self.node_uuid)
         self.assertFalse(mock_list_partitions.called)
-        self.assertFalse(mock_is_disk_gpt.called)
         self.assertFalse(mock_execute.called)
+        self.assertFalse(mock_is_disk_gpt.called)
+        self.assertFalse(mock_fix_gpt.called)
         mock_dd.assert_called_with(configdrive_file, configdrive_part)
         mock_unlink.assert_called_with(configdrive_file)
 
@@ -999,6 +1058,8 @@ class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
                        autospec=True)
     @mock.patch.object(disk_utils, 'dd',
                        autospec=True)
+    @mock.patch.object(disk_utils, '_fix_gpt_partition',
+                       autospec=True)
     @mock.patch.object(disk_utils, '_fix_gpt_structs',
                        autospec=True)
     @mock.patch.object(disk_utils, '_is_disk_gpt_partitioned',
@@ -1012,8 +1073,8 @@ class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
     def test_create_partition_gpt(self, mock_get_configdrive,
                                   mock_get_labelled_partition,
                                   mock_list_partitions, mock_is_disk_gpt,
-                                  mock_fix_gpt, mock_dd, mock_unlink,
-                                  mock_execute):
+                                  mock_fix_gpt, mock_fix_gpt_partition,
+                                  mock_dd, mock_unlink, mock_execute):
         config_url = 'http://1.2.3.4/cd'
         configdrive_file = '/tmp/xyz'
         configdrive_mb = 10
@@ -1054,7 +1115,9 @@ class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
 
         self.assertEqual(2, mock_list_partitions.call_count)
         mock_is_disk_gpt.assert_called_with(self.dev, self.node_uuid)
-        mock_fix_gpt.assert_called_with(self.dev, self.node_uuid)
+        mock_fix_gpt_partition.assert_called_with(self.dev, self.node_uuid)
+        self.assertFalse(mock_fix_gpt.called)
+        mock_fix_gpt_partition.assert_called_with(self.dev, self.node_uuid)
         mock_dd.assert_called_with(configdrive_file, expected_part)
         mock_unlink.assert_called_with(configdrive_file)
 
@@ -1067,6 +1130,8 @@ class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
                        autospec=True)
     @mock.patch.object(disk_utils, '_is_disk_larger_than_max_size',
                        autospec=True)
+    @mock.patch.object(disk_utils, '_fix_gpt_partition',
+                       autospec=True)
     @mock.patch.object(disk_utils, '_fix_gpt_structs',
                        autospec=True)
     @mock.patch.object(disk_utils, '_is_disk_gpt_partitioned',
@@ -1081,10 +1146,12 @@ class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
                                    mock_get_labelled_partition,
                                    mock_list_partitions,
                                    mock_is_disk_gpt, mock_fix_gpt,
+                                   mock_fix_gpt_partition,
                                    mock_disk_exceeds, mock_dd,
                                    mock_unlink, mock_log, mock_execute,
                                    mock_count, disk_size_exceeds_max=False,
-                                   is_iscsi_device=False):
+                                   is_iscsi_device=False,
+                                   is_nvme_device=False):
         config_url = 'http://1.2.3.4/cd'
         configdrive_file = '/tmp/xyz'
         configdrive_mb = 10
@@ -1119,6 +1186,9 @@ class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
             self.dev = ('/dev/iqn.2008-10.org.openstack:%s.fake' %
                         self.node_uuid)
             expected_part = '%s-part4' % self.dev
+        elif is_nvme_device:
+            self.dev = '/dev/nvmefake'
+            expected_part = '%sp4' % self.dev
         else:
             expected_part = '/dev/fake4'
 
@@ -1145,19 +1215,33 @@ class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
         ])
         self.assertEqual(2, mock_list_partitions.call_count)
         mock_is_disk_gpt.assert_called_with(self.dev, self.node_uuid)
+        mock_fix_gpt_partition.assert_called_with(self.dev, self.node_uuid)
         mock_disk_exceeds.assert_called_with(self.dev, self.node_uuid)
         mock_dd.assert_called_with(configdrive_file, expected_part)
         mock_unlink.assert_called_with(configdrive_file)
         self.assertFalse(mock_fix_gpt.called)
+        self.assertFalse(mock_fix_gpt.called)
         mock_count.assert_called_with(self.dev)
 
     def test__create_partition_mbr_disk_under_2TB(self):
         self._test_create_partition_mbr(disk_size_exceeds_max=False,
-                                        is_iscsi_device=True)
+                                        is_iscsi_device=True,
+                                        is_nvme_device=False)
+
+    def test__create_partition_mbr_disk_under_2TB_nvme(self):
+        self._test_create_partition_mbr(disk_size_exceeds_max=False,
+                                        is_iscsi_device=False,
+                                        is_nvme_device=True)
 
     def test__create_partition_mbr_disk_exceeds_2TB(self):
         self._test_create_partition_mbr(disk_size_exceeds_max=True,
-                                        is_iscsi_device=False)
+                                        is_iscsi_device=False,
+                                        is_nvme_device=False)
+
+    def test__create_partition_mbr_disk_exceeds_2TB_nvme(self):
+        self._test_create_partition_mbr(disk_size_exceeds_max=True,
+                                        is_iscsi_device=False,
+                                        is_nvme_device=True)
 
     @mock.patch.object(disk_utils, 'count_mbr_partitions', autospec=True)
     @mock.patch.object(utils, 'execute', autospec=True)
@@ -1167,6 +1251,8 @@ class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
                        autospec=True)
     @mock.patch.object(disk_utils, '_is_disk_larger_than_max_size',
                        autospec=True)
+    @mock.patch.object(disk_utils, '_fix_gpt_partition',
+                       autospec=True)
     @mock.patch.object(disk_utils, '_fix_gpt_structs',
                        autospec=True)
     @mock.patch.object(disk_utils, '_is_disk_gpt_partitioned',
@@ -1181,6 +1267,7 @@ class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
                                                mock_get_labelled_partition,
                                                mock_list_partitions,
                                                mock_is_disk_gpt, mock_fix_gpt,
+                                               mock_fix_gpt_partition,
                                                mock_disk_exceeds, mock_dd,
                                                mock_unlink, mock_execute,
                                                mock_count):
@@ -1223,6 +1310,7 @@ class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
                                         'fat32', '-64MiB', '-0',
                                         run_as_root=True)
         self.assertEqual(2, mock_list_partitions.call_count)
+        mock_fix_gpt_partition.assert_called_with(self.dev, self.node_uuid)
         mock_is_disk_gpt.assert_called_with(self.dev, self.node_uuid)
         mock_disk_exceeds.assert_called_with(self.dev, self.node_uuid)
         self.assertFalse(mock_fix_gpt.called)
@@ -1238,6 +1326,8 @@ class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
                        autospec=True)
     @mock.patch.object(disk_utils, '_is_disk_larger_than_max_size',
                        autospec=True)
+    @mock.patch.object(disk_utils, '_fix_gpt_partition',
+                       autospec=True)
     @mock.patch.object(disk_utils, '_fix_gpt_structs',
                        autospec=True)
     @mock.patch.object(disk_utils, '_is_disk_gpt_partitioned',
@@ -1252,6 +1342,7 @@ class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
                                               mock_get_labelled_partition,
                                               mock_list_partitions,
                                               mock_is_disk_gpt, mock_fix_gpt,
+                                              mock_fix_gpt_partition,
                                               mock_disk_exceeds, mock_dd,
                                               mock_unlink, mock_execute,
                                               mock_count):
@@ -1288,6 +1379,7 @@ class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
                                         'fat32', '-64MiB', '-0',
                                         run_as_root=True)
         self.assertEqual(1, mock_list_partitions.call_count)
+        mock_fix_gpt_partition.assert_called_with(self.dev, self.node_uuid)
         mock_is_disk_gpt.assert_called_with(self.dev, self.node_uuid)
         mock_disk_exceeds.assert_called_with(self.dev, self.node_uuid)
         self.assertFalse(mock_fix_gpt.called)
@@ -1300,6 +1392,8 @@ class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
                        autospec=True)
     @mock.patch.object(disk_utils, 'dd',
                        autospec=True)
+    @mock.patch.object(disk_utils, '_fix_gpt_partition',
+                       autospec=True)
     @mock.patch.object(disk_utils, '_fix_gpt_structs',
                        autospec=True)
     @mock.patch.object(disk_utils, '_is_disk_gpt_partitioned',
@@ -1314,6 +1408,7 @@ class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
                                                mock_get_labelled_partition,
                                                mock_list_partitions,
                                                mock_is_disk_gpt, mock_fix_gpt,
+                                               mock_fix_gpt_partition,
                                                mock_dd, mock_unlink,
                                                mock_count):
         config_url = 'http://1.2.3.4/cd'
@@ -1343,6 +1438,7 @@ class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
 
         mock_get_configdrive.assert_called_with(config_url, self.node_uuid)
         self.assertEqual(1, mock_list_partitions.call_count)
+        mock_fix_gpt_partition.assert_called_with(self.dev, self.node_uuid)
         mock_is_disk_gpt.assert_called_with(self.dev, self.node_uuid)
         self.assertFalse(mock_fix_gpt.called)
         self.assertFalse(mock_dd.called)
@@ -1378,6 +1474,8 @@ class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
     @mock.patch.object(utils, 'execute', autospec=True)
     @mock.patch.object(utils, 'unlink_without_raise',
                        autospec=True)
+    @mock.patch.object(disk_utils, '_fix_gpt_partition',
+                       autospec=True)
     @mock.patch.object(disk_utils, '_is_disk_gpt_partitioned',
                        autospec=True)
     @mock.patch.object(disk_utils, '_get_labelled_partition',
@@ -1386,7 +1484,8 @@ class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
                        autospec=True)
     def test_create_partition_conf_drive_error_counting(
             self, mock_get_configdrive, mock_get_labelled_partition,
-            mock_is_disk_gpt, mock_unlink, mock_execute, mock_count):
+            mock_is_disk_gpt, mock_fix_gpt_partition,
+            mock_unlink, mock_execute, mock_count):
         config_url = 'http://1.2.3.4/cd'
         configdrive_file = '/tmp/xyz'
         configdrive_mb = 10
@@ -1403,5 +1502,6 @@ class WholeDiskConfigDriveTestCases(test_base.BaseTestCase):
 
         mock_get_configdrive.assert_called_with(config_url, self.node_uuid)
         mock_unlink.assert_called_with(configdrive_file)
+        mock_fix_gpt_partition.assert_called_with(self.dev, self.node_uuid)
         mock_is_disk_gpt.assert_called_with(self.dev, self.node_uuid)
         mock_count.assert_called_once_with(self.dev)
